@@ -33,6 +33,7 @@ from pulp_ansible.app.galaxy.mixins import UploadGalaxyCollectionMixin
 from .models import (
     AnsibleCollectionDeprecated,
     AnsibleDistribution,
+    GitRemote,
     RoleRemote,
     AnsibleRepository,
     Collection,
@@ -43,6 +44,7 @@ from .models import (
 )
 from .serializers import (
     AnsibleDistributionSerializer,
+    GitRemoteSerializer,
     RoleRemoteSerializer,
     AnsibleRepositorySerializer,
     AnsibleRepositorySyncURLSerializer,
@@ -58,6 +60,7 @@ from .serializers import (
 from .tasks.collections import update_collection_remote, sync as collection_sync
 from .tasks.copy import copy_content
 from .tasks.roles import synchronize as role_sync
+from .tasks.git import synchronize as git_sync
 
 
 class RoleFilter(ContentFilter):
@@ -225,6 +228,18 @@ class RoleRemoteViewSet(RemoteViewSet):
     serializer_class = RoleRemoteSerializer
 
 
+class GitRemoteViewSet(RemoteViewSet):
+    """
+    ViewSet for Ansible Remotes.
+
+    This is a tech preview feature. The functionality may change in the future.
+    """
+
+    endpoint_name = "git"
+    queryset = GitRemote.objects.all()
+    serializer_class = GitRemoteSerializer
+
+
 class AnsibleRepositoryViewSet(RepositoryViewSet, ModifyRepositoryActionMixin):
     """
     ViewSet for Ansible Repositories.
@@ -264,10 +279,13 @@ class AnsibleRepositoryViewSet(RepositoryViewSet, ModifyRepositoryActionMixin):
         elif isinstance(remote, CollectionRemote):
             sync_func = collection_sync
             sync_kwargs["optimize"] = serializer.validated_data["optimize"]
+        elif isinstance(remote, GitRemote):
+            sync_func = git_sync
 
         result = dispatch(
             sync_func,
-            exclusive_resources=[repository, remote],
+            exclusive_resources=[repository],
+            shared_resources=[remote],
             kwargs=sync_kwargs,
         )
         return OperationPostponedResponse(result, request)
@@ -399,9 +417,14 @@ class CopyViewSet(viewsets.ViewSet):
 
         config = serializer.validated_data["config"]
 
-        config, repos = self._process_config(config)
+        config, exclusive_resources, shared_resources = self._process_config(config)
 
-        async_result = dispatch(copy_content, exclusive_resources=repos, args=[config], kwargs={})
+        async_result = dispatch(
+            copy_content,
+            exclusive_resources=exclusive_resources,
+            shared_resources=shared_resources,
+            args=[config],
+        )
         return OperationPostponedResponse(async_result, request)
 
     def _process_config(self, config):
@@ -412,7 +435,8 @@ class CopyViewSet(viewsets.ViewSet):
         repos so that the task can lock on them.
         """
         result = []
-        repos = []
+        exclusive_resources = []
+        shared_resources = []
 
         for entry in config:
             r = dict()
@@ -422,7 +446,8 @@ class CopyViewSet(viewsets.ViewSet):
             dest_repo = NamedModelViewSet().get_resource(entry["dest_repo"], AnsibleRepository)
             r["source_repo_version"] = source_version.pk
             r["dest_repo"] = dest_repo.pk
-            repos.extend((source_version.repository, dest_repo))
+            exclusive_resources.append(dest_repo)
+            shared_resources.append(source_version.repository)
 
             if "dest_base_version" in entry:
                 try:
@@ -441,4 +466,4 @@ class CopyViewSet(viewsets.ViewSet):
                     r["content"].append(NamedModelViewSet().extract_pk(c))
             result.append(r)
 
-        return result, repos
+        return result, exclusive_resources, shared_resources
